@@ -94,10 +94,10 @@ mc.crisk.pwbart <- function(
     pred$K <- K
 
     pred$yhat.test <- yhat.test.list[[1]]
-    if(class(pred$yhat.test)!='matrix') return(pred$yhat.test)
+    if(class(pred$yhat.test)[1]!='matrix') return(pred$yhat.test)
 
     pred$yhat.test2 <- yhat.test2.list[[1]]
-    if(class(pred$yhat.test)!='matrix') return(pred$yhat.test)
+    if(class(pred$yhat.test)[1]!='matrix') return(pred$yhat.test)
 
     if(mc.cores>1)
         for(i in 2:mc.cores) {
