@@ -26,6 +26,7 @@
 #include "bd.h"
 #include "bart.h"
 #include "rtnorm.h"
+//#include "rtruncnorm.h"
 
 #ifndef NoRcpp
 
@@ -133,7 +134,7 @@ RcppExport SEXP cpbart(
      for(size_t i=0;i<p;i++) {
        _xi[i].resize(numcut[i]);
        //Rcpp::IntegerVector cutpts(Xinfo[i]);
-       for(size_t j=0;j<numcut[i];j++) _xi[i][j]=Xinfo(i, j);
+       for(size_t j=0;j<(size_t)numcut[i];j++) _xi[i][j]=Xinfo(i, j);
      }
      bm.setxinfo(_xi);
    }
@@ -263,6 +264,10 @@ void cpbart(
   for(size_t k=0; k<n; k++) {
     if(iy[k]==0) iz[k]= -rtnorm(0., binaryOffset, 1., gen);
     else iz[k]=rtnorm(0., -binaryOffset, 1., gen);
+/*
+    if(iy[k]==0) iz[k]= -r_lefttruncnorm(0., binaryOffset, 1., gen);
+    else iz[k]=r_lefttruncnorm(0., -binaryOffset, 1., gen);
+*/
   }
 
    //--------------------------------------------------
@@ -297,6 +302,10 @@ void cpbart(
   for(size_t k=0; k<n; k++) {
     if(iy[k]==0) iz[k]= -rtnorm(-bm.f(k), binaryOffset, 1., gen);
     else iz[k]=rtnorm(bm.f(k), -binaryOffset, 1., gen);
+/*
+    if(iy[k]==0) iz[k]= -r_lefttruncnorm(-bm.f(k), binaryOffset, 1., gen);
+    else iz[k]=r_lefttruncnorm(bm.f(k), -binaryOffset, 1., gen);
+*/
   }
 
       if(i>=burn) {
